# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator (autorest: 3.0.6320, generator: {generator})
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

try:
    from ._models_py3 import Answer
    from ._models_py3 import CreativeWork
    from ._models_py3 import Error
    from ._models_py3 import ErrorResponse
    from ._models_py3 import Identifiable
    from ._models_py3 import Query
    from ._models_py3 import QueryContext
    from ._models_py3 import Response
    from ._models_py3 import ResponseBase
    from ._models_py3 import SearchResponse
    from ._models_py3 import SearchResultsAnswer
    from ._models_py3 import Thing
    from ._models_py3 import WebAnswer
    from ._models_py3 import WebMetaTag
    from ._models_py3 import WebPage
except (SyntaxError, ImportError):
    from ._models import Answer  # type: ignore
    from ._models import CreativeWork  # type: ignore
    from ._models import Error  # type: ignore
    from ._models import ErrorResponse  # type: ignore
    from ._models import Identifiable  # type: ignore
    from ._models import Query  # type: ignore
    from ._models import QueryContext  # type: ignore
    from ._models import Response  # type: ignore
    from ._models import ResponseBase  # type: ignore
    from ._models import SearchResponse  # type: ignore
    from ._models import SearchResultsAnswer  # type: ignore
    from ._models import Thing  # type: ignore
    from ._models import WebAnswer  # type: ignore
    from ._models import WebMetaTag  # type: ignore
    from ._models import WebPage  # type: ignore

from ._custom_search_client_enums import (
    ErrorCode,
    ErrorSubCode,
    SafeSearch,
    TextFormat,
    XBingApisSDK,
)

__all__ = [
    'Answer',
    'CreativeWork',
    'Error',
    'ErrorResponse',
    'Identifiable',
    'Query',
    'QueryContext',
    'Response',
    'ResponseBase',
    'SearchResponse',
    'SearchResultsAnswer',
    'Thing',
    'WebAnswer',
    'WebMetaTag',
    'WebPage',
    'ErrorCode',
    'ErrorSubCode',
    'SafeSearch',
    'TextFormat',
    'XBingApisSDK',
]
